@@ -5,27 +5,26 @@ import codecs
 import configparser
 import os
 import re
-import requests
 import sys
 import time
 from functools import update_wrapper
 
 import click
-# from click_aliases import ClickAliasedGroup
+import requests
 
-from apigee import APP
-from apigee import CMD
+from apigee import APP, CMD
 from apigee import __version__ as version
 from apigee.apiproducts.commands import apiproducts
 from apigee.apis.commands import apis
 from apigee.apps.commands import apps
 from apigee.auth import auth
+from apigee.backups.commands import backups
 from apigee.caches.commands import caches
 from apigee.cls import AliasedGroup
 from apigee.configure.commands import configure
 from apigee.deployments.commands import deployments
 from apigee.developers.commands import developers
-from apigee.exception import exception_handler
+from apigee.exceptions import exception_handler
 from apigee.keyvaluemaps.commands import keyvaluemaps
 from apigee.maskconfigs.commands import maskconfigs
 from apigee.permissions.commands import permissions
@@ -33,9 +32,10 @@ from apigee.targetservers.commands import targetservers
 from apigee.userroles.commands import userroles
 from apigee.utils import show_message
 
-CONTEXT_SETTINGS = dict(
-    help_option_names=["-h", "--help"]
-)
+# from click_aliases import ClickAliasedGroup
+
+
+CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 
 @click.group(context_settings=CONTEXT_SETTINGS, cls=AliasedGroup, invoke_without_command=False, chain=False)
@@ -58,24 +58,32 @@ def cli(ctx):
     # by means other than the `if` block below)
     ctx.ensure_object(dict)
 
+
 @exception_handler
 def main():
-    cli.add_command(configure)
-    cli.add_command(deployments)
-    cli.add_command(caches)
-    cli.add_command(keyvaluemaps)
-    cli.add_command(targetservers)
-    cli.add_command(apis)
-    cli.add_command(apiproducts)
-    cli.add_command(apps)
-    cli.add_command(developers)
-    cli.add_command(auth)
-    cli.add_command(maskconfigs)
-    cli.add_command(userroles)
-    cli.add_command(permissions)
+    cli_commands = (
+        backups,
+        configure,
+        deployments,
+        caches,
+        keyvaluemaps,
+        targetservers,
+        apis,
+        apiproducts,
+        apps,
+        developers,
+        auth,
+        maskconfigs,
+        userroles,
+        permissions,
+    )
+
+    for command in cli_commands:
+        cli.add_command(command)
+
     cli(prog_name=CMD, obj={})
 
 
 if __name__ == '__main__':
     # cli() # pragma: no cover
-    main() # pragma: no cover
+    main()  # pragma: no cover
