@@ -2,7 +2,7 @@ import builtins
 import sys
 
 
-def echo(*message, status=None, silent=False, curr_verbosity=0, expc_verbosity=0):
+def echo(*message, status=None, silent=False, curr_verbosity=0, expc_verbosity=0, end='\n', flush=False):
     toggle_silent = False
     toggle_verbose = 0
     try:
@@ -15,6 +15,6 @@ def echo(*message, status=None, silent=False, curr_verbosity=0, expc_verbosity=0
             sys.exit(status)
         return
     if curr_verbosity or toggle_verbose >= expc_verbosity:
-        print(*message)
+        print(*message, end=end, flush=flush)
     if status:
         sys.exit(status)
